/**
 * @brief The AVR Timer module
 * @details This file is used to interact with the hardware timers.
 * @author Jake G
 * @date 2024
 * @copyright None
 * @file TIMER.h
 */

#ifndef TIMER
#define TIMER

#include "inttypes.h"
#include "stdbool.h"

/**
 * Starts up the AVR timer using a 10KHz frequency
 */
void Timer_Start(void);

/**
 * Stops the AVR timer.
 */
void Timer_Stop(void);

/**
 * Get the number of times the timer's counter setup for 10kHz overflowed.
 * @return A uint16_t holding the number of counter overflow events.
 */
uint16_t Timer_GetOverflowCount(void);

#endif // TIMER
